==> kmymoney_5.1.2.orig.tar.xz: kmymoney-5.1.2/kmymoney/plugins/kbanking/kbanking.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "aquamaniac@users.sourceforge.net,ipwizard@users.sourceforge.net,christian-david@web.de",
                "Name": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[ca@valencia]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[ca]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[de]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[en_GB]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[es]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[et]": "Martin Preuss, Thomas Baumgart, Christian Dávid",
                "Name[eu]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[fi]": "Martin Preuss, Thomas Baumgart, Christian Dávid",
                "Name[fr]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[gl]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[ia]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[it]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[ko]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[nl]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[pl]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[pt]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[pt_BR]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[ru]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[sk]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[sl]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[sv]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[uk]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[x-test]": "xxMartin Preuss,Thomas Baumgart,Christian Dávidxx",
                "Name[zh_CN]": "Martin Preuss,Thomas Baumgart,Christian Dávid"
            }
        ],
        "Description": "Add HBCI/FinTs, OFX and PayPal online banking to KMyMoney",
        "Description[ca@valencia]": "Afig la banca en línia HBCI/FinTs, OFX i PayPal al KMyMoney",
        "Description[ca]": "Afegeix la banca en línia HBCI/FinTs, OFX i PayPal al KMyMoney",
        "Description[en_GB]": "Add HBCI/FinTs, OFX and PayPal online banking to KMyMoney",
        "Description[es]": "Añade banca en línea HBCI/FinTs, OFX y PayPal a KMyMoney",
        "Description[fr]": "Ajoute des capacités de banque HBCI/FinTs, OFS et PayPal en ligne à KMyMoney",
        "Description[it]": "Aggiungi servizi bancari in linea HBCI/FinTs, OFX e PayPal a KMyMoney",
        "Description[ko]": "KMyMoney에 HBCI/FinTs, OFX, PayPal 온라인 뱅킹 추가",
        "Description[nl]": "Voegt HBCI/FinTs, OFX en PayPal online bankieren toe aan KMyMoney",
        "Description[pl]": "Dodaje obsługę bankowości sieciowej HBCI/FinTs, OFX oraz PayPal do KMyMoney",
        "Description[pt_BR]": "Adiciona correspondente bancário do tipo HBCI/FinTs, OFX e PayPal no KMyMoney",
        "Description[sl]": "Doda spletno bančništvo HBCI/FinTs, OFX in PayPal v KMyMoney",
        "Description[sv]": "Lägg till HBCI/FinTs Internetbank och PayPal till KMyMoney",
        "Description[uk]": "Онлайн-банкінг HBCI/FinTs, OFX і PayPal у KMyMoney",
        "Description[x-test]": "xxAdd HBCI/FinTs, OFX and PayPal online banking to KMyMoneyxx",
        "EnabledByDefault": true,
        "Icon": "network-connect",
        "Id": "kbanking",
        "License": "GPL",
        "Name": "KBanking",
        "Name[ca@valencia]": "KBanking",
        "Name[ca]": "KBanking",
        "Name[cs]": "KBanking",
        "Name[de]": "KBanking",
        "Name[en_GB]": "KBanking",
        "Name[es]": "KBanking",
        "Name[et]": "KBanking",
        "Name[eu]": "KBanking",
        "Name[fi]": "KBanking",
        "Name[fr]": "KBanking",
        "Name[gl]": "KBanking",
        "Name[it]": "KBanking",
        "Name[ko]": "KBanking",
        "Name[nl]": "KBanking",
        "Name[pl]": "KBanking",
        "Name[pt]": "KBanking",
        "Name[pt_BR]": "KBanking",
        "Name[ru]": "KBanking",
        "Name[sk]": "KBanking",
        "Name[sl]": "KBanking",
        "Name[sv]": "Kbank",
        "Name[uk]": "KBanking",
        "Name[x-test]": "xxKBankingxx",
        "Name[zh_CN]": "KBanking",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney_5.1.3.orig.tar.xz: kmymoney-5.1.3/kmymoney/plugins/kbanking/kbanking.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "aquamaniac@users.sourceforge.net,ipwizard@users.sourceforge.net,christian-david@web.de",
                "Name": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[ca@valencia]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[ca]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[de]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[en_GB]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[es]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[et]": "Martin Preuss, Thomas Baumgart, Christian Dávid",
                "Name[eu]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[fi]": "Martin Preuss, Thomas Baumgart, Christian Dávid",
                "Name[fr]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[gl]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[ia]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[it]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[ko]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[nl]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[pl]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[pt]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[pt_BR]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[ru]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[sk]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[sl]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[sv]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[uk]": "Martin Preuss,Thomas Baumgart,Christian Dávid",
                "Name[x-test]": "xxMartin Preuss,Thomas Baumgart,Christian Dávidxx",
                "Name[zh_CN]": "Martin Preuss,Thomas Baumgart,Christian Dávid"
            }
        ],
        "Description": "Add HBCI/FinTs, OFX and PayPal online banking to KMyMoney",
        "Description[ca@valencia]": "Afig la banca en línia HBCI/FinTs, OFX i PayPal a KMyMoney",
        "Description[ca]": "Afegeix la banca en línia HBCI/FinTs, OFX i PayPal al KMyMoney",
        "Description[en_GB]": "Add HBCI/FinTs, OFX and PayPal online banking to KMyMoney",
        "Description[es]": "Añade banca en línea HBCI/FinTs, OFX y PayPal a KMyMoney",
        "Description[fr]": "Ajoute des capacités de banque HBCI/FinTs, OFS et PayPal en ligne à KMyMoney",
        "Description[it]": "Aggiungi servizi bancari in linea HBCI/FinTs, OFX e PayPal a KMyMoney",
        "Description[ko]": "KMyMoney에 HBCI/FinTs, OFX, PayPal 온라인 뱅킹 추가",
        "Description[nl]": "Voegt HBCI/FinTs, OFX en PayPal online bankieren toe aan KMyMoney",
        "Description[pl]": "Dodaje obsługę bankowości sieciowej HBCI/FinTs, OFX oraz PayPal do KMyMoney",
        "Description[pt_BR]": "Adiciona correspondente bancário do tipo HBCI/FinTs, OFX e PayPal no KMyMoney",
        "Description[ru]": "Добавляет в KMyMoney возможность сетевой работы с банками (HBCI/FinTs, OFX и PayPal)",
        "Description[sl]": "Doda spletno bančništvo HBCI/FinTs, OFX in PayPal v KMyMoney",
        "Description[sv]": "Lägg till HBCI/FinTs Internetbank och PayPal till KMyMoney",
        "Description[uk]": "Онлайн-банкінг HBCI/FinTs, OFX і PayPal у KMyMoney",
        "Description[x-test]": "xxAdd HBCI/FinTs, OFX and PayPal online banking to KMyMoneyxx",
        "Description[zh_CN]": "将 HBCI (FinTs)、OFX 或 PayPal 网上银行添加到 KMyMoney",
        "EnabledByDefault": true,
        "Icon": "network-connect",
        "Id": "kbanking",
        "License": "GPL",
        "Name": "KBanking",
        "Name[ca@valencia]": "KBanking",
        "Name[ca]": "KBanking",
        "Name[cs]": "KBanking",
        "Name[de]": "KBanking",
        "Name[en_GB]": "KBanking",
        "Name[es]": "KBanking",
        "Name[et]": "KBanking",
        "Name[eu]": "KBanking",
        "Name[fi]": "KBanking",
        "Name[fr]": "KBanking",
        "Name[gl]": "KBanking",
        "Name[ia]": "Kbanking",
        "Name[it]": "KBanking",
        "Name[ko]": "KBanking",
        "Name[nl]": "KBanking",
        "Name[pl]": "KBanking",
        "Name[pt]": "KBanking",
        "Name[pt_BR]": "KBanking",
        "Name[ru]": "KBanking",
        "Name[sk]": "KBanking",
        "Name[sl]": "KBanking",
        "Name[sv]": "Kbank",
        "Name[uk]": "KBanking",
        "Name[x-test]": "xxKBankingxx",
        "Name[zh_CN]": "KBanking",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
